@@ -7,7 +7,7 @@
 ** 
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
+** the Free Software Foundation; either version 3 of the License, or
 ** (at your option) any later version.
 ** 
 ** This program is distributed in the hope that it will be useful,
@@ -29,6 +29,7 @@
 **           GNU Project
 **
 */
+#include "ac_config.h"
 
 /*
  * This code is derived from:
@@ -45,7 +46,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -66,6 +67,11 @@
 #include <stdlib.h>
 #include <ctype.h>
 
+#include "ac_config.h"
+#ifdef HAVE_INTTYPES_H
+  #include <inttypes.h>
+#endif
+
 #ifndef SEEK_SET
 #   define SEEK_SET 0
 #endif
@@ -143,10 +149,10 @@
 #else 
 #   define PT(aaa) ()
 #endif
-static Boolean set_new_scale        PT(());
+static Boolean set_new_scale        PT((void));
 static Boolean set_new_orientation  PT((int));
 static Boolean set_new_pagemedia    PT((int));
-static void    layout_ghostview     PT(());
+static void    layout_ghostview     PT((void));
 #undef PT
 
 /*############################################################*/
@@ -707,6 +713,9 @@ show_page(number,data1)
       }
       need_layout = need_setup = 
           set_new_orientation(number)|set_new_pagemedia(number);
+//TODO?
+      if (need_layout && !app_res.auto_resize && gv_scales[gv_scale]->scale <= 0)
+          set_new_scale();
       need_render = True;
    } else if (request<NO_CURRENT_PAGE) {
       INFIMESSAGE(analyzing,request)
@@ -728,9 +737,9 @@ show_page(number,data1)
       case REQUEST_SETUP:
 		INFMESSAGE(### request for setup)
 		number=current_page;
-		need_layout =	set_new_scale()
-				|set_new_orientation(number)
-				|set_new_pagemedia(number);
+		need_layout =	set_new_orientation(number)
+				|set_new_pagemedia(number)
+				|set_new_scale();
                 need_setup  = True;
 		need_render = True;
 		break;
@@ -1090,7 +1099,7 @@ Dimension page_width, page_height;
 /*------------------------------------------------------------*/
 
 static void
-layout_ghostview()
+layout_ghostview(void)
 {
    Arg       args[10];
    Cardinal  n;
@@ -1170,19 +1179,21 @@ setup_layout_ghostview()
 /*------------------------------------------------------------*/
 
 static Boolean
-set_new_scale()
+set_new_scale(void)
 {
   int new_scale,new_scale_base;
   Boolean changed = False;
   Arg args[2];
   Cardinal n;
   Scale scale;
+  float ascale;
 
   BEGINMESSAGE(set_new_scale)
 
   new_scale_base = gv_scale_base;
   if (!default_xdpi || !default_ydpi || new_scale_base != gv_scale_base_current) {
     scale = gv_scales[new_scale_base];
+    ascale = scale->scale;
     if ((scale->is_base)&SCALE_IS_REAL_BASED) {
       default_xdpi = gv_real_xdpi; 
       default_ydpi = gv_real_ydpi;
@@ -1190,8 +1201,8 @@ set_new_scale()
       default_xdpi = gv_pixel_xdpi; 
       default_ydpi = gv_pixel_ydpi;
     }
-    default_xdpi *= scale->scale;
-    default_ydpi *= scale->scale;
+    default_xdpi *= ascale;
+    default_ydpi *= ascale;
     XtSetArg(args[0], XtNleftBitmap, None);
     if (gv_scale_base_current >=0) XtSetValues(scaleEntry[gv_scale_base_current],args, ONE);
     XtSetArg(args[0], XtNleftBitmap, app_res.selected_bitmap);
@@ -1201,12 +1212,50 @@ set_new_scale()
   }
   
   new_scale = gv_scale;
-  if (changed || new_scale != gv_scale_current) {
+  if (changed || new_scale != gv_scale_current || gv_scales[new_scale]->scale <=0) {
     float xdpi, ydpi;
     GhostviewDisableInterpreter(page);
     scale = gv_scales[new_scale];
-    xdpi = default_xdpi / scale->scale;
-    ydpi = default_ydpi / scale->scale;
+    ascale = scale->scale;
+
+    if (!ascale)
+    {
+       int dx = current_urx - current_llx + 1;
+       int dy = current_ury - current_lly + 1;
+       
+       if (gv_orientation == 2 || gv_orientation == 3)
+       {
+          int hlp = dx;
+	  dx = dy;
+	  dy = hlp;
+       }
+       
+       float ascale1 = (float)viewClip->core.width / dx / 72.0 * default_xdpi;
+       float ascale2 = (float)viewClip->core.height / dy / 72.0 * default_ydpi;
+       
+       ascale = ascale1 < ascale2 ? ascale1 : ascale2;
+    }
+    else if (fabs(ascale+1) <= 0.001)
+    {
+       int dx = current_urx - current_llx + 1;
+       int dy = current_ury - current_lly + 1;
+       
+       if (gv_orientation == 2 || gv_orientation == 3)
+       {
+          int hlp = dx;
+	  dx = dy;
+	  dy = hlp;
+       }
+       
+       ascale = (float)viewClip->core.width / dx / 72.0 * default_xdpi;
+    }
+    else if (fabs(ascale+2) <= 0.001)
+    {
+       ascale = gv_ascale;
+    }
+    
+    xdpi = default_xdpi / ascale;
+    ydpi = default_ydpi / ascale;
                                               n=0;
     XtSetArg(args[n], XtNlabel, scale->name); n++;
     XtSetValues(scaleButton, args, n);
@@ -1492,7 +1541,7 @@ set_new_pagemedia(pagenumber)
 /*------------------------------------------------------------*/
 
 static Boolean
-same_document_media()
+same_document_media(void)
 {
    int i;
    Boolean same = True;
@@ -1549,7 +1598,7 @@ void misc_buildPagemediaMenu()
   if (doc && doc->nummedia) {
     for (i = 0; i < doc->nummedia; i++) {
       pagemediaEntry[i] = XtCreateManagedWidget(doc->media[i].name,smeBSBObjectClass, pagemediaMenu,NULL,(Cardinal)0);
-      XtAddCallback(pagemediaEntry[i], XtNcallback,cb_setPagemedia, (XtPointer)i);
+      XtAddCallback(pagemediaEntry[i], XtNcallback,cb_setPagemedia, (XtPointer)(intptr_t)i);
     }
     w = XtCreateManagedWidget("line", smeLineObjectClass, pagemediaMenu,NULL,(Cardinal)0);
   }
@@ -1559,7 +1608,7 @@ void misc_buildPagemediaMenu()
     if (!(gv_medias[i]->used)) continue;
     pagemediaEntry[i+num_doc_media] = 
       XtCreateManagedWidget(gv_medias[i]->name,smeBSBObjectClass, pagemediaMenu,NULL,(Cardinal)0);
-    XtAddCallback(pagemediaEntry[i+num_doc_media], XtNcallback,cb_setPagemedia, (XtPointer)(i+num_doc_media));
+    XtAddCallback(pagemediaEntry[i+num_doc_media], XtNcallback,cb_setPagemedia, (XtPointer)(intptr_t)(i+num_doc_media));
   }
   {
     Boolean b = (doc_mediaIsOk(doc,current_page,num_doc_media) ? True : False);
