@@ -7,7 +7,7 @@
 ** 
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
+** the Free Software Foundation; either version 3 of the License, or
 ** (at your option) any later version.
 ** 
 ** This program is distributed in the hope that it will be useful,
@@ -29,6 +29,7 @@
 **           GNU Project
 **
 */
+#include "ac_config.h"
 
 /*
 #define MESSAGES
@@ -64,8 +65,8 @@
 static Widget popup,optionControl;
 static Widget filter,scratch_dir,default_save_dir,filters,dirs;
 
-static void options_fs_create();
-static void options_fs_setOptionsAtEntry();
+static void options_fs_create(void);
+static void options_fs_setOptionsAtEntry(void);
 
 /*------------------------------------------------------
   OptionPopupStruct
@@ -84,7 +85,7 @@ OptionPopup gv_options_fs = (OptionPopup) &gv_options_fs_struct;
    options_fs_setOptionsAtEntry
 ------------------------------------------------------*/
 
-static void options_fs_setOptionsAtEntry()
+static void options_fs_setOptionsAtEntry(void)
 {
   String s;
 
@@ -171,7 +172,7 @@ void options_fs_cb_save(w, client_data, call_data)
    options_fs_create
 ------------------------------------------------------*/
 
-static void options_fs_create()
+static void options_fs_create(void)
 {
    Arg          args[10];
    Cardinal     n;
