@@ -7,7 +7,7 @@
 ** 
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
+** the Free Software Foundation; either version 3 of the License, or
 ** (at your option) any later version.
 ** 
 ** This program is distributed in the hope that it will be useful,
@@ -29,6 +29,7 @@
 **           GNU Project
 **
 */
+#include "ac_config.h"
 
 /*
 #define MESSAGES
@@ -40,6 +41,11 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <ctype.h>
+#include <math.h>
+
+#ifdef HAVE_INTTYPES_H
+  #include <inttypes.h>
+#endif
 
 #include "paths.h"
 #include INC_X11(Intrinsic.h)
@@ -75,6 +81,8 @@ static Widget   popup=NULL,optionControl;
 static Widget   antialiasToggle;
 static Widget   dscToggle,eofToggle,autoResizeToggle;
 static Widget   swapLandscapeToggle,watchToggle;
+static Widget   infoPopupLabel,infoPopupButton,infoPopupMenu;
+static Widget   ascaleLabel, ascale;
 static Widget   mediaLabel,mediaButton,mediaMenu=NULL;
 static Widget   fmediaLabel,fmediaButton,fmediaMenu=NULL;
 static Widget   orientLabel,orientButton,orientMenu;
@@ -86,8 +94,11 @@ static String orientations[5] = { "Portrait","Landscape","Upside-Down","Seascape
 static int opt_orientation;
 static int opt_pagemedia;
 
-static void options_gv_create();
-static void options_gv_setOptionsAtEntry();
+static String popupVerb[5] = { "None", "Errors", "All", NULL };
+static String popupVerbExtern[5] = { "Silent", "Errors", "All", NULL };
+
+static void options_gv_create(void);
+static void options_gv_setOptionsAtEntry(void);
 
 /*------------------------------------------------------
   OptionPopupStruct
@@ -106,7 +117,7 @@ OptionPopup gv_options_gv = (OptionPopup) &gv_options_gv_struct;
    options_gv_setOptionsAtEntry
 ------------------------------------------------------*/
 
-static void options_gv_setOptionsAtEntry()
+static void options_gv_setOptionsAtEntry(void)
 {
   String s;
   Arg args[2];
@@ -143,6 +154,17 @@ static void options_gv_setOptionsAtEntry()
   XtSetArg(args[n], XtNlabel, s);  n++;
   XtSetValues(forientButton, args, n);
 
+  s=popupVerb[gv_infoVerbose];
+                                   n=0;
+  XtSetArg(args[n], XtNlabel, s);  n++;
+  XtSetValues(infoPopupButton, args, n);
+
+  {
+     char number[80];
+     sprintf(number, "%.3f", gv_ascale*gv_ascale);
+     widgets_setText(ascale, number);
+  }
+  
   ENDMESSAGE(options_gv_setOptionsAtEntry)
 }
 
@@ -195,8 +217,11 @@ static void options_gv_cb_apply(w, client_data, call_data)
    static Boolean s_forient = False;
    Boolean b;
    int i,j,k;
+   char* l;
    Boolean redisplay=False;
    Boolean reopen=False;
+   String v;
+   float Ascale;
 
    BEGINMESSAGE(options_gv_cb_apply)
 
@@ -252,7 +277,7 @@ static void options_gv_cb_apply(w, client_data, call_data)
      k = gv_pagemedia;
      gv_pagemedia_auto = 0;
      i = doc_convStringToPageMedia(doc,app_res.default_pagemedia);
-     cb_setPagemedia(NULL,(XtPointer)i,(XtPointer)1);
+     cb_setPagemedia(NULL,(XtPointer)(intptr_t)i,(XtPointer)1);
      if ((j != gv_pagemedia_auto) || (k != gv_pagemedia)) redisplay = True;
    }
    s_media = True;
@@ -277,7 +302,7 @@ static void options_gv_cb_apply(w, client_data, call_data)
      j = gv_orientation_auto;
      k = gv_orientation;
      gv_orientation_auto = 0;
-     cb_setOrientation(NULL,(XtPointer)i,(XtPointer)1);
+     cb_setOrientation(NULL,(XtPointer)i,(XtPointer)(intptr_t)1);
      if ((j != gv_orientation_auto) || (k != gv_orientation)) redisplay = True;
    }
    s_orient = True;
@@ -300,6 +325,28 @@ static void options_gv_cb_apply(w, client_data, call_data)
       redisplay = True;
    }
 
+							n=0;
+   XtSetArg(args[n], XtNlabel, &l);                     n++;
+   XtGetValues(infoPopupButton, args, n);
+   i=0;j=0;
+   while (i<3) {
+     if (!strcmp(popupVerb[i],l)) j = i;
+     ++i;
+   }
+   if (j != gv_infoVerbose) {
+     gv_infoVerbose = j;
+   }
+   
+   v = options_squeeze(widgets_getText(ascale));
+   sscanf(v, "%f", &Ascale);
+   Ascale=sqrt(Ascale);
+   if (Ascale != gv_ascale)
+   {
+      gv_ascale = Ascale;
+      redisplay = True;
+   }
+
+
    if (reopen && gv_filename) {
      cb_stopInterpreter(page,NULL,NULL);
      show_page(REQUEST_REOPEN,NULL);
@@ -370,6 +417,18 @@ void options_gv_cb_save(w, client_data, call_data)
        ++argn;
   }
 
+
+	         	       	        n=0;
+  XtSetArg(args[n], XtNlabel, &l);      n++;
+  XtGetValues(infoPopupButton, args, n);
+  i=0; while (i<3) {
+     if (!strcmp(popupVerb[i],l)) sprintf(tmp,"%s",popupVerbExtern[i]);
+     ++i;
+   }
+  options_setArg(&(argi[argn]),&(argv[argn]),s_infoVerbose        ,gv_class        ,tmp);
+       ++argn;
+
+
   options_save(argn,argi,argv);
   while (--argn >=0) {
     GV_XtFree(argi[argn]); 
@@ -500,7 +559,7 @@ void options_gv_createMediaMenus()
    options_gv_create
 ------------------------------------------------------*/
 
-void options_gv_create()
+void options_gv_create(void)
 {
    Arg          args[10];
    Cardinal     n;
@@ -543,6 +602,14 @@ void options_gv_create()
        XtAddCallback(w, XtNcallback,options_cb_changeMenuLabel,NULL); 
      }
         						n=0;
+options_createLabeledMenu("infoVerbose",optionControl,&infoPopupLabel,&infoPopupButton,&infoPopupMenu);
+     for (i = 0; popupVerb[i]; i++) {
+       w = XtCreateManagedWidget(popupVerb[i],smeBSBObjectClass, infoPopupMenu,NULL,(Cardinal)0);
+       XtAddCallback(w, XtNcallback,options_cb_changeMenuLabel,NULL);
+     }
+
+   ascale = widgets_createLabeledLineTextField("ascale", optionControl);
+
    w = XtCreateManagedWidget("apply", buttonWidgetClass,optionControl, args, n);
          XtAddCallback(w, XtNcallback, options_gv_cb_apply,NULL); 
          XtInstallAccelerators(optionControl, w);
