@@ -7,7 +7,7 @@
 ** 
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
+** the Free Software Foundation; either version 3 of the License, or
 ** (at your option) any later version.
 ** 
 ** This program is distributed in the hope that it will be useful,
@@ -29,6 +29,7 @@
 **           GNU Project
 **
 */
+#include "ac_config.h"
 
 #define _GV_RESOURCE_C_
 
@@ -93,7 +94,7 @@ static String resource_system_file = NULL;
 static String resource_user_file   = NULL;
 static String resource_style_file  = NULL;
 static String resource_ad_file     = NULL;
-static char* resource_mergeFileIntoDatabase();
+static char* resource_mergeFileIntoDatabase(XrmDatabase*,char*);
 
 /*#######################################################
   resource_freeData
@@ -125,7 +126,6 @@ resource_buildDatabase (
   XrmDatabase db = NULL;
   String *sP;
   String s,t, rpath;
-  char *spartan_filename;
   char tmp[GV_MAX_FILENAME_LENGTH];
 
   BEGINMESSAGE(resource_buildDatabase)
@@ -215,7 +215,7 @@ resource_buildDatabase (
     }
   if (spartan_p)
     {
-      spartan_filename = (char *) 
+      char *spartan_filename = (char *)
 	GV_XtMalloc (strlen(GV_LIBDIR) + strlen ("/gv_spartan.dat") + 1);
       spartan_filename[0] = '\0';
       strcat(spartan_filename, GV_LIBDIR);
@@ -223,10 +223,26 @@ resource_buildDatabase (
       resource_putResource (&db, app_name, ".style", spartan_filename);
       GV_XtFree (spartan_filename);
     }
+  if (widgetless_p)
+    {
+      char *widgetless_filename = (char *)
+	GV_XtMalloc (strlen(GV_LIBDIR) + strlen ("/gv_widgetless.dat") + 1);
+      widgetless_filename[0] = '\0';
+      strcat(widgetless_filename, GV_LIBDIR);
+      strcat(widgetless_filename, "/gv_widgetless.dat");
+      resource_putResource (&db, app_name, ".style", widgetless_filename);
+      GV_XtFree (widgetless_filename);
+    }
   if (quiet_p)
     {
       resource_putResource (&db, app_name, ".gsQuiet", "True");
     }
+  if (infoverbose_p != -1)
+    {
+      if (infoverbose_p == 0) resource_putResource (&db, app_name, ".infoVerbose", "Silent");
+      if (infoverbose_p == 1) resource_putResource (&db, app_name, ".infoVerbose", "Errors");
+      if (infoverbose_p == 2) resource_putResource (&db, app_name, ".infoVerbose", "All");
+    }
   if (monochrome_p)
     {
       resource_putResource (&db, app_name, "*Ghostview.palette", "Monochrome");
@@ -332,12 +348,15 @@ resource_buildDatabase (
 #   ifdef USE_FALLBACK_STYLES
     sP = NULL;
 #     ifdef FALLBACK_STYLE_1_DAT
+    if (!strcmp(GV_LIBDIR "/" FALLBACK_STYLE_1_DAT,s)) sP = fallback_style_1;
     if (!strcmp(FALLBACK_STYLE_1_DAT,s)) sP = fallback_style_1;
 #     endif
 #     ifdef FALLBACK_STYLE_2_DAT
+    if (!strcmp(GV_LIBDIR "/" FALLBACK_STYLE_2_DAT,s)) sP = fallback_style_2;
     if (!strcmp(FALLBACK_STYLE_2_DAT,s)) sP = fallback_style_2;
 #     endif
 #     ifdef FALLBACK_STYLE_3_DAT
+    if (!strcmp(GV_LIBDIR "/" FALLBACK_STYLE_3_DAT,s)) sP = fallback_style_3;
     if (!strcmp(FALLBACK_STYLE_3_DAT,s)) sP = fallback_style_3;
 #     endif
     if (sP) {
